# Make Art Project
import board, time, analogio, digitalio, neopixel, pwmio, math, adafruit_vl53l1x
from audiopwmio import PWMAudioOut as AudioOut
from audiocore import WaveFile


strip_pin = board.A1
strip_num_of_lights = 30
strip = neopixel.NeoPixel(strip_pin, strip_num_of_lights)

# Prior video also shows setup code changes for Raspberry Pi Pico & QT Py RP2040
i2c = board.I2C()
distance_sensor = adafruit_vl53l1x.VL53L1X(i2c)
distance_sensor.distance_mode = 1
distance_sensor.timing_budget = 100

distance_sensor.start_ranging()

MAX_DISTANCE = 150
MIN_DISTANCE = 0
cm_per_light = (MAX_DISTANCE-MIN_DISTANCE)/strip_num_of_lights


# speaker
speaker = digitalio.DigitalInOut(board.SPEAKER_ENABLE)
speaker.direction = digitalio.Direction.OUTPUT
speaker.value = True
audio = AudioOut(board.SPEAKER)

RED = (255, 0, 0)
GREEN = (0, 255, 0)
BLACK = (0, 0, 0)
YELLOW = (255, 150, 0)

def go():
    for i in range(20, 30):
        strip[i] = GREEN
        time.sleep(0.1)
    else:
        for i in range(strip_num_of_lights):
            strip[i] = BLACK
def slow():
    for i in range(10, 20):
        strip[i] = YELLOW
        time.sleep(0.1)
    else:
        for i in range(strip_num_of_lights):
            strip[i] = BLACK
def stop():
    for i in range(0, 10):
        strip[i] = RED
        time.sleep(0.1)
    else:
        for i in range(strip_num_of_lights):
            strip[i] = BLACK




# sound
path = "Sounds/"


def play_sound(sound):
    if sound == "go":
        with open (path + "go.wav", "rb") as wave_file:
            wave = WaveFile(wave_file)
            audio.play(wave)
            while audio.playing:
                go()
    if sound == "slow":
        with open (path + "slow.wav", "rb") as wave_file:
            wave = WaveFile(wave_file)
            audio.play(wave)
            while audio.playing:
                slow()
    if sound == "stop":
        with open (path + "stop.wav", "rb") as wave_file:
            wave = WaveFile(wave_file)
            audio.play(wave)
            while audio.playing:
                stop()


while True:
    if distance_sensor.data_ready:
        distance = distance_sensor.distance
        if distance == None:
            distance = 0
        print("Distance: ", distance)
        if distance == 0: # do nothing if 0 reading, which shows up if nothing is in front of sensor
            continue # this skips the rest of the code & restarts the loop
        distance = min(distance, MAX_DISTANCE)
        distance = max(distance, MIN_DISTANCE)

        if distance > 80:
            play_sound ("go")

        if distance < 80 and distance > 40:
            play_sound("slow")


        if distance < 40 and distance > 0:
            play_sound("stop")


        distance_sensor.clear_interrupt()
        time.sleep(0.05)


